@@ -2,11 +2,15 @@ from __future__ import annotations
 
 import argparse
 import sys
+from typing import Any
 
 from django.apps import apps
 from django.core.management.commands.makemigrations import Command as BaseCommand
+from django.db.migrations.loader import MigrationLoader
 
-from django_linear_migrations.apps import MigrationDetails, first_party_app_configs
+from django_linear_migrations.apps import first_party_app_configs
+from django_linear_migrations.apps import get_graph_plan
+from django_linear_migrations.apps import MigrationDetails
 
 
 class Command(BaseCommand):
@@ -40,7 +44,7 @@ class Command(BaseCommand):
         )
 
     def handle(
-        self, *app_labels: str, dry_run: bool, recreate: bool, **options: object
+        self, *app_labels: str, dry_run: bool, recreate: bool, **options: Any
     ) -> None:
         # Copied check from makemigrations
         labels = set(app_labels)
@@ -55,6 +59,8 @@ class Command(BaseCommand):
             sys.exit(2)
 
         any_created = False
+        migration_loader = MigrationLoader(None, ignore_no_migrations=True)
+        graph_plan = get_graph_plan(loader=migration_loader, app_labels=labels)
         for app_config in first_party_app_configs():
             if labels and app_config.label not in labels:
                 continue
@@ -66,7 +72,9 @@ class Command(BaseCommand):
             max_migration_txt = migration_details.dir / "max_migration.txt"
             if recreate or not max_migration_txt.exists():
                 if not dry_run:
-                    max_migration_name = max(migration_details.names)
+                    max_migration_name = [
+                        k[1] for k in graph_plan if k[0] == app_config.label
+                    ][-1]
                     max_migration_txt.write_text(max_migration_name + "\n")
                     self.stdout.write(
                         f"Created max_migration.txt for {app_config.label}."
